# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yamcs/protobuf/server/server_service.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yamcs.api import annotations_pb2 as yamcs_dot_api_dot_annotations__pb2
from yamcs.api import httpbody_pb2 as yamcs_dot_api_dot_httpbody__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yamcs/protobuf/server/server_service.proto',
  package='yamcs.protobuf.server',
  syntax='proto2',
  serialized_options=b'\n\022org.yamcs.protobufB\022ServerServiceProtoP\001',
  serialized_pb=b'\n*yamcs/protobuf/server/server_service.proto\x12\x15yamcs.protobuf.server\x1a\x1egoogle/protobuf/duration.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1byamcs/api/annotations.proto\x1a\x18yamcs/api/httpbody.proto\"\x1e\n\x10GetThreadRequest\x12\n\n\x02id\x18\x01 \x01(\x03\"I\n\x13ListThreadsResponse\x12\x32\n\x07threads\x18\x01 \x03(\x0b\x32!.yamcs.protobuf.server.ThreadInfo\"F\n\x12ListRoutesResponse\x12\x30\n\x06routes\x18\x01 \x03(\x0b\x32 .yamcs.protobuf.server.RouteInfo\"F\n\x12ListTopicsResponse\x12\x30\n\x06topics\x18\x01 \x03(\x0b\x32 .yamcs.protobuf.server.TopicInfo\"\xa9\x01\n\x0bHttpTraffic\x12\x11\n\treadBytes\x18\x01 \x01(\x04\x12\x14\n\x0cwrittenBytes\x18\x02 \x01(\x04\x12\x16\n\x0ereadThroughput\x18\x03 \x01(\x04\x12\x17\n\x0fwriteThroughput\x18\x04 \x01(\x04\x12@\n\x0b\x63onnections\x18\x05 \x03(\x0b\x32+.yamcs.protobuf.server.ClientConnectionInfo\"\xda\x01\n\tRouteInfo\x12\x0f\n\x07service\x18\x01 \x01(\t\x12\x0e\n\x06method\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x12\n\nhttpMethod\x18\x04 \x01(\t\x12\x0b\n\x03url\x18\x05 \x01(\t\x12\x11\n\tinputType\x18\x06 \x01(\t\x12\x12\n\noutputType\x18\x07 \x01(\t\x12\x12\n\ndeprecated\x18\x08 \x01(\x08\x12\x14\n\x0crequestCount\x18\t \x01(\x03\x12\x12\n\nerrorCount\x18\n \x01(\x03\x12\x11\n\tlogFormat\x18\x0b \x01(\t\"\x8b\x01\n\tTopicInfo\x12\r\n\x05topic\x18\x01 \x01(\t\x12\x0f\n\x07service\x18\x02 \x01(\t\x12\x0e\n\x06method\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x11\n\tinputType\x18\x05 \x01(\t\x12\x12\n\noutputType\x18\x06 \x01(\t\x12\x12\n\ndeprecated\x18\x07 \x01(\x08\"_\n\x10TraceElementInfo\x12\x11\n\tclassName\x18\x01 \x01(\t\x12\x10\n\x08\x66ileName\x18\x02 \x01(\t\x12\x12\n\nmethodName\x18\x03 \x01(\t\x12\x12\n\nlineNumber\x18\x04 \x01(\x05\"#\n\x12ListThreadsRequest\x12\r\n\x05\x64\x65pth\x18\x01 \x01(\x05\"W\n\x0fThreadGroupInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x36\n\x06parent\x18\x03 \x01(\x0b\x32&.yamcs.protobuf.server.ThreadGroupInfo\"\xc7\x01\n\nThreadInfo\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05state\x18\x03 \x01(\t\x12\x0e\n\x06native\x18\x04 \x01(\x08\x12\x11\n\tsuspended\x18\x05 \x01(\x08\x12\x35\n\x05group\x18\x06 \x01(\x0b\x32&.yamcs.protobuf.server.ThreadGroupInfo\x12\x36\n\x05trace\x18\x07 \x03(\x0b\x32\'.yamcs.protobuf.server.TraceElementInfo\"\xb5\x03\n\x15GetServerInfoResponse\x12\x14\n\x0cyamcsVersion\x18\x01 \x01(\t\x12\x10\n\x08revision\x18\x06 \x01(\t\x12\x10\n\x08serverId\x18\x02 \x01(\t\x12\x1c\n\x14\x64\x65\x66\x61ultYamcsInstance\x18\x03 \x01(\t\x12H\n\x07plugins\x18\x05 \x03(\x0b\x32\x37.yamcs.protobuf.server.GetServerInfoResponse.PluginInfo\x12V\n\x0e\x63ommandOptions\x18\x07 \x03(\x0b\x32>.yamcs.protobuf.server.GetServerInfoResponse.CommandOptionInfo\x1aP\n\nPluginInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\t\x12\x0e\n\x06vendor\x18\x04 \x01(\t\x1aP\n\x11\x43ommandOptionInfo\x12\n\n\x02id\x18\x01 \x01(\t\x12\x13\n\x0bverboseName\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\x12\x0c\n\x04help\x18\x04 \x01(\t\"\x8f\x03\n\x14\x43lientConnectionInfo\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04open\x18\x02 \x01(\x08\x12\x0e\n\x06\x61\x63tive\x18\x03 \x01(\x08\x12\x10\n\x08writable\x18\x04 \x01(\x08\x12\x15\n\rremoteAddress\x18\x05 \x01(\t\x12\x11\n\treadBytes\x18\x06 \x01(\x04\x12\x14\n\x0cwrittenBytes\x18\x07 \x01(\x04\x12\x16\n\x0ereadThroughput\x18\x08 \x01(\x04\x12\x17\n\x0fwriteThroughput\x18\t \x01(\x04\x12P\n\x0bhttpRequest\x18\n \x01(\x0b\x32;.yamcs.protobuf.server.ClientConnectionInfo.HttpRequestInfo\x12\x10\n\x08username\x18\x0b \x01(\t\x1a\x66\n\x0fHttpRequestInfo\x12\x10\n\x08protocol\x18\x01 \x01(\t\x12\x0e\n\x06method\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\x11\n\tkeepAlive\x18\x04 \x01(\x08\x12\x11\n\tuserAgent\x18\x05 \x01(\t\"\xbe\x05\n\nSystemInfo\x12\x14\n\x0cyamcsVersion\x18\x01 \x01(\t\x12\x10\n\x08revision\x18\x02 \x01(\t\x12\x10\n\x08serverId\x18\x03 \x01(\t\x12\x0e\n\x06uptime\x18\x05 \x01(\x03\x12\x0b\n\x03jvm\x18\x06 \x01(\t\x12\x18\n\x10workingDirectory\x18\x07 \x01(\t\x12\x17\n\x0f\x63onfigDirectory\x18\x08 \x01(\t\x12\x15\n\rdataDirectory\x18\t \x01(\t\x12\x16\n\x0e\x63\x61\x63heDirectory\x18\n \x01(\t\x12\n\n\x02os\x18\x0b \x01(\t\x12\x0c\n\x04\x61rch\x18\x0c \x01(\t\x12\x1b\n\x13\x61vailableProcessors\x18\r \x01(\x05\x12\x13\n\x0bloadAverage\x18\x0e \x01(\x01\x12\x12\n\nheapMemory\x18\x0f \x01(\x03\x12\x16\n\x0eusedHeapMemory\x18\x10 \x01(\x03\x12\x15\n\rmaxHeapMemory\x18\x11 \x01(\x03\x12\x15\n\rnonHeapMemory\x18\x12 \x01(\x03\x12\x19\n\x11usedNonHeapMemory\x18\x13 \x01(\x03\x12\x18\n\x10maxNonHeapMemory\x18\x14 \x01(\x03\x12\x16\n\x0ejvmThreadCount\x18\x15 \x01(\x03\x12=\n\x0frootDirectories\x18\x16 \x03(\x0b\x32$.yamcs.protobuf.server.RootDirectory\x12\x33\n\x07process\x18\x17 \x01(\x0b\x32\".yamcs.protobuf.server.ProcessInfo\x12\x0f\n\x07\x63puTime\x18\x18 \x01(\x03\x12\x0f\n\x07\x63puLoad\x18\x19 \x01(\x01\x12\x16\n\x0eprocessCpuLoad\x18\x1a \x01(\x01\x12\x12\n\nfreeMemory\x18\x1b \x01(\x03\x12\x13\n\x0btotalMemory\x18\x1c \x01(\x03\x12\x15\n\rfreeSwapSpace\x18\x1d \x01(\x03\x12\x16\n\x0etotalSwapSpace\x18\x1e \x01(\x03\"s\n\rRootDirectory\x12\x11\n\tdirectory\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x12\n\ntotalSpace\x18\x03 \x01(\x03\x12\x18\n\x10unallocatedSpace\x18\x04 \x01(\x03\x12\x13\n\x0busableSpace\x18\x05 \x01(\x03\"\xe6\x01\n\x0bProcessInfo\x12\x0b\n\x03pid\x18\x01 \x01(\x03\x12\x0c\n\x04user\x18\x02 \x01(\t\x12\x0f\n\x07\x63ommand\x18\x03 \x01(\t\x12\x11\n\targuments\x18\x04 \x03(\t\x12-\n\tstartTime\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x33\n\x10totalCpuDuration\x18\x06 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x34\n\x08\x63hildren\x18\x07 \x03(\x0b\x32\".yamcs.protobuf.server.ProcessInfo2\xbc\x08\n\tServerApi\x12\x61\n\rGetServerInfo\x12\x16.google.protobuf.Empty\x1a,.yamcs.protobuf.server.GetServerInfoResponse\"\n\x8a\x92\x03\x06\n\x04/api\x12^\n\rGetSystemInfo\x12\x16.google.protobuf.Empty\x1a!.yamcs.protobuf.server.SystemInfo\"\x12\x8a\x92\x03\x0e\n\x0c/api/sysinfo\x12\x61\n\x13SubscribeSystemInfo\x12\x16.google.protobuf.Empty\x1a!.yamcs.protobuf.server.SystemInfo\"\r\xda\x92\x03\t\n\x07sysinfo0\x01\x12\x62\n\nListRoutes\x12\x16.google.protobuf.Empty\x1a).yamcs.protobuf.server.ListRoutesResponse\"\x11\x8a\x92\x03\r\n\x0b/api/routes\x12\x62\n\nListTopics\x12\x16.google.protobuf.Empty\x1a).yamcs.protobuf.server.ListTopicsResponse\"\x11\x8a\x92\x03\r\n\x0b/api/topics\x12x\n\x0bListThreads\x12).yamcs.protobuf.server.ListThreadsRequest\x1a*.yamcs.protobuf.server.ListThreadsResponse\"\x12\x8a\x92\x03\x0e\n\x0c/api/threads\x12p\n\tGetThread\x12\'.yamcs.protobuf.server.GetThreadRequest\x1a!.yamcs.protobuf.server.ThreadInfo\"\x17\x8a\x92\x03\x13\n\x11/api/threads/{id}\x12S\n\x0b\x44umpThreads\x12\x16.google.protobuf.Empty\x1a\x13.yamcs.api.HttpBody\"\x17\x8a\x92\x03\x13\n\x11/api/threads:dump\x12w\n\x0eGetHttpTraffic\x12\x16.google.protobuf.Empty\x1a\".yamcs.protobuf.server.HttpTraffic\")\x8a\x92\x03%\n\x11/api/http-trafficj\x10Get HTTP Traffic\x12\x80\x01\n\x14SubscribeHttpTraffic\x12\x16.google.protobuf.Empty\x1a\".yamcs.protobuf.server.HttpTraffic\"*\xda\x92\x03&\n\x0chttp-traffic\"\x16Subscribe HTTP Traffic0\x01\x1a\x04\xd0\x80\x01\x01\x42*\n\x12org.yamcs.protobufB\x12ServerServiceProtoP\x01'
  ,
  dependencies=[google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,yamcs_dot_api_dot_annotations__pb2.DESCRIPTOR,yamcs_dot_api_dot_httpbody__pb2.DESCRIPTOR,])




_GETTHREADREQUEST = _descriptor.Descriptor(
  name='GetThreadRequest',
  full_name='yamcs.protobuf.server.GetThreadRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yamcs.protobuf.server.GetThreadRequest.id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=218,
  serialized_end=248,
)


_LISTTHREADSRESPONSE = _descriptor.Descriptor(
  name='ListThreadsResponse',
  full_name='yamcs.protobuf.server.ListThreadsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='threads', full_name='yamcs.protobuf.server.ListThreadsResponse.threads', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=250,
  serialized_end=323,
)


_LISTROUTESRESPONSE = _descriptor.Descriptor(
  name='ListRoutesResponse',
  full_name='yamcs.protobuf.server.ListRoutesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='routes', full_name='yamcs.protobuf.server.ListRoutesResponse.routes', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=325,
  serialized_end=395,
)


_LISTTOPICSRESPONSE = _descriptor.Descriptor(
  name='ListTopicsResponse',
  full_name='yamcs.protobuf.server.ListTopicsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='topics', full_name='yamcs.protobuf.server.ListTopicsResponse.topics', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=397,
  serialized_end=467,
)


_HTTPTRAFFIC = _descriptor.Descriptor(
  name='HttpTraffic',
  full_name='yamcs.protobuf.server.HttpTraffic',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='readBytes', full_name='yamcs.protobuf.server.HttpTraffic.readBytes', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='writtenBytes', full_name='yamcs.protobuf.server.HttpTraffic.writtenBytes', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='readThroughput', full_name='yamcs.protobuf.server.HttpTraffic.readThroughput', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='writeThroughput', full_name='yamcs.protobuf.server.HttpTraffic.writeThroughput', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='connections', full_name='yamcs.protobuf.server.HttpTraffic.connections', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=470,
  serialized_end=639,
)


_ROUTEINFO = _descriptor.Descriptor(
  name='RouteInfo',
  full_name='yamcs.protobuf.server.RouteInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='service', full_name='yamcs.protobuf.server.RouteInfo.service', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='method', full_name='yamcs.protobuf.server.RouteInfo.method', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description', full_name='yamcs.protobuf.server.RouteInfo.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='httpMethod', full_name='yamcs.protobuf.server.RouteInfo.httpMethod', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='url', full_name='yamcs.protobuf.server.RouteInfo.url', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='inputType', full_name='yamcs.protobuf.server.RouteInfo.inputType', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='outputType', full_name='yamcs.protobuf.server.RouteInfo.outputType', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deprecated', full_name='yamcs.protobuf.server.RouteInfo.deprecated', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='requestCount', full_name='yamcs.protobuf.server.RouteInfo.requestCount', index=8,
      number=9, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='errorCount', full_name='yamcs.protobuf.server.RouteInfo.errorCount', index=9,
      number=10, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='logFormat', full_name='yamcs.protobuf.server.RouteInfo.logFormat', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=642,
  serialized_end=860,
)


_TOPICINFO = _descriptor.Descriptor(
  name='TopicInfo',
  full_name='yamcs.protobuf.server.TopicInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='topic', full_name='yamcs.protobuf.server.TopicInfo.topic', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='service', full_name='yamcs.protobuf.server.TopicInfo.service', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='method', full_name='yamcs.protobuf.server.TopicInfo.method', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description', full_name='yamcs.protobuf.server.TopicInfo.description', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='inputType', full_name='yamcs.protobuf.server.TopicInfo.inputType', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='outputType', full_name='yamcs.protobuf.server.TopicInfo.outputType', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deprecated', full_name='yamcs.protobuf.server.TopicInfo.deprecated', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=863,
  serialized_end=1002,
)


_TRACEELEMENTINFO = _descriptor.Descriptor(
  name='TraceElementInfo',
  full_name='yamcs.protobuf.server.TraceElementInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='className', full_name='yamcs.protobuf.server.TraceElementInfo.className', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fileName', full_name='yamcs.protobuf.server.TraceElementInfo.fileName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='methodName', full_name='yamcs.protobuf.server.TraceElementInfo.methodName', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lineNumber', full_name='yamcs.protobuf.server.TraceElementInfo.lineNumber', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1004,
  serialized_end=1099,
)


_LISTTHREADSREQUEST = _descriptor.Descriptor(
  name='ListThreadsRequest',
  full_name='yamcs.protobuf.server.ListThreadsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='depth', full_name='yamcs.protobuf.server.ListThreadsRequest.depth', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1101,
  serialized_end=1136,
)


_THREADGROUPINFO = _descriptor.Descriptor(
  name='ThreadGroupInfo',
  full_name='yamcs.protobuf.server.ThreadGroupInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.server.ThreadGroupInfo.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parent', full_name='yamcs.protobuf.server.ThreadGroupInfo.parent', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1138,
  serialized_end=1225,
)


_THREADINFO = _descriptor.Descriptor(
  name='ThreadInfo',
  full_name='yamcs.protobuf.server.ThreadInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yamcs.protobuf.server.ThreadInfo.id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.server.ThreadInfo.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state', full_name='yamcs.protobuf.server.ThreadInfo.state', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='native', full_name='yamcs.protobuf.server.ThreadInfo.native', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='suspended', full_name='yamcs.protobuf.server.ThreadInfo.suspended', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='group', full_name='yamcs.protobuf.server.ThreadInfo.group', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='trace', full_name='yamcs.protobuf.server.ThreadInfo.trace', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1228,
  serialized_end=1427,
)


_GETSERVERINFORESPONSE_PLUGININFO = _descriptor.Descriptor(
  name='PluginInfo',
  full_name='yamcs.protobuf.server.GetServerInfoResponse.PluginInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.server.GetServerInfoResponse.PluginInfo.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description', full_name='yamcs.protobuf.server.GetServerInfoResponse.PluginInfo.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='version', full_name='yamcs.protobuf.server.GetServerInfoResponse.PluginInfo.version', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vendor', full_name='yamcs.protobuf.server.GetServerInfoResponse.PluginInfo.vendor', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1705,
  serialized_end=1785,
)

_GETSERVERINFORESPONSE_COMMANDOPTIONINFO = _descriptor.Descriptor(
  name='CommandOptionInfo',
  full_name='yamcs.protobuf.server.GetServerInfoResponse.CommandOptionInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yamcs.protobuf.server.GetServerInfoResponse.CommandOptionInfo.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='verboseName', full_name='yamcs.protobuf.server.GetServerInfoResponse.CommandOptionInfo.verboseName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='yamcs.protobuf.server.GetServerInfoResponse.CommandOptionInfo.type', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='help', full_name='yamcs.protobuf.server.GetServerInfoResponse.CommandOptionInfo.help', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1787,
  serialized_end=1867,
)

_GETSERVERINFORESPONSE = _descriptor.Descriptor(
  name='GetServerInfoResponse',
  full_name='yamcs.protobuf.server.GetServerInfoResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='yamcsVersion', full_name='yamcs.protobuf.server.GetServerInfoResponse.yamcsVersion', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='revision', full_name='yamcs.protobuf.server.GetServerInfoResponse.revision', index=1,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='serverId', full_name='yamcs.protobuf.server.GetServerInfoResponse.serverId', index=2,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='defaultYamcsInstance', full_name='yamcs.protobuf.server.GetServerInfoResponse.defaultYamcsInstance', index=3,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='plugins', full_name='yamcs.protobuf.server.GetServerInfoResponse.plugins', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='commandOptions', full_name='yamcs.protobuf.server.GetServerInfoResponse.commandOptions', index=5,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_GETSERVERINFORESPONSE_PLUGININFO, _GETSERVERINFORESPONSE_COMMANDOPTIONINFO, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1430,
  serialized_end=1867,
)


_CLIENTCONNECTIONINFO_HTTPREQUESTINFO = _descriptor.Descriptor(
  name='HttpRequestInfo',
  full_name='yamcs.protobuf.server.ClientConnectionInfo.HttpRequestInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='protocol', full_name='yamcs.protobuf.server.ClientConnectionInfo.HttpRequestInfo.protocol', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='method', full_name='yamcs.protobuf.server.ClientConnectionInfo.HttpRequestInfo.method', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uri', full_name='yamcs.protobuf.server.ClientConnectionInfo.HttpRequestInfo.uri', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='keepAlive', full_name='yamcs.protobuf.server.ClientConnectionInfo.HttpRequestInfo.keepAlive', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='userAgent', full_name='yamcs.protobuf.server.ClientConnectionInfo.HttpRequestInfo.userAgent', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2167,
  serialized_end=2269,
)

_CLIENTCONNECTIONINFO = _descriptor.Descriptor(
  name='ClientConnectionInfo',
  full_name='yamcs.protobuf.server.ClientConnectionInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yamcs.protobuf.server.ClientConnectionInfo.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='open', full_name='yamcs.protobuf.server.ClientConnectionInfo.open', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='active', full_name='yamcs.protobuf.server.ClientConnectionInfo.active', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='writable', full_name='yamcs.protobuf.server.ClientConnectionInfo.writable', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remoteAddress', full_name='yamcs.protobuf.server.ClientConnectionInfo.remoteAddress', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='readBytes', full_name='yamcs.protobuf.server.ClientConnectionInfo.readBytes', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='writtenBytes', full_name='yamcs.protobuf.server.ClientConnectionInfo.writtenBytes', index=6,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='readThroughput', full_name='yamcs.protobuf.server.ClientConnectionInfo.readThroughput', index=7,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='writeThroughput', full_name='yamcs.protobuf.server.ClientConnectionInfo.writeThroughput', index=8,
      number=9, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='httpRequest', full_name='yamcs.protobuf.server.ClientConnectionInfo.httpRequest', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='username', full_name='yamcs.protobuf.server.ClientConnectionInfo.username', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CLIENTCONNECTIONINFO_HTTPREQUESTINFO, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1870,
  serialized_end=2269,
)


_SYSTEMINFO = _descriptor.Descriptor(
  name='SystemInfo',
  full_name='yamcs.protobuf.server.SystemInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='yamcsVersion', full_name='yamcs.protobuf.server.SystemInfo.yamcsVersion', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='revision', full_name='yamcs.protobuf.server.SystemInfo.revision', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='serverId', full_name='yamcs.protobuf.server.SystemInfo.serverId', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uptime', full_name='yamcs.protobuf.server.SystemInfo.uptime', index=3,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='jvm', full_name='yamcs.protobuf.server.SystemInfo.jvm', index=4,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='workingDirectory', full_name='yamcs.protobuf.server.SystemInfo.workingDirectory', index=5,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='configDirectory', full_name='yamcs.protobuf.server.SystemInfo.configDirectory', index=6,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dataDirectory', full_name='yamcs.protobuf.server.SystemInfo.dataDirectory', index=7,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cacheDirectory', full_name='yamcs.protobuf.server.SystemInfo.cacheDirectory', index=8,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='os', full_name='yamcs.protobuf.server.SystemInfo.os', index=9,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='arch', full_name='yamcs.protobuf.server.SystemInfo.arch', index=10,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='availableProcessors', full_name='yamcs.protobuf.server.SystemInfo.availableProcessors', index=11,
      number=13, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='loadAverage', full_name='yamcs.protobuf.server.SystemInfo.loadAverage', index=12,
      number=14, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='heapMemory', full_name='yamcs.protobuf.server.SystemInfo.heapMemory', index=13,
      number=15, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='usedHeapMemory', full_name='yamcs.protobuf.server.SystemInfo.usedHeapMemory', index=14,
      number=16, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='maxHeapMemory', full_name='yamcs.protobuf.server.SystemInfo.maxHeapMemory', index=15,
      number=17, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nonHeapMemory', full_name='yamcs.protobuf.server.SystemInfo.nonHeapMemory', index=16,
      number=18, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='usedNonHeapMemory', full_name='yamcs.protobuf.server.SystemInfo.usedNonHeapMemory', index=17,
      number=19, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='maxNonHeapMemory', full_name='yamcs.protobuf.server.SystemInfo.maxNonHeapMemory', index=18,
      number=20, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='jvmThreadCount', full_name='yamcs.protobuf.server.SystemInfo.jvmThreadCount', index=19,
      number=21, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rootDirectories', full_name='yamcs.protobuf.server.SystemInfo.rootDirectories', index=20,
      number=22, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='process', full_name='yamcs.protobuf.server.SystemInfo.process', index=21,
      number=23, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cpuTime', full_name='yamcs.protobuf.server.SystemInfo.cpuTime', index=22,
      number=24, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cpuLoad', full_name='yamcs.protobuf.server.SystemInfo.cpuLoad', index=23,
      number=25, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processCpuLoad', full_name='yamcs.protobuf.server.SystemInfo.processCpuLoad', index=24,
      number=26, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='freeMemory', full_name='yamcs.protobuf.server.SystemInfo.freeMemory', index=25,
      number=27, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='totalMemory', full_name='yamcs.protobuf.server.SystemInfo.totalMemory', index=26,
      number=28, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='freeSwapSpace', full_name='yamcs.protobuf.server.SystemInfo.freeSwapSpace', index=27,
      number=29, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='totalSwapSpace', full_name='yamcs.protobuf.server.SystemInfo.totalSwapSpace', index=28,
      number=30, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2272,
  serialized_end=2974,
)


_ROOTDIRECTORY = _descriptor.Descriptor(
  name='RootDirectory',
  full_name='yamcs.protobuf.server.RootDirectory',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='directory', full_name='yamcs.protobuf.server.RootDirectory.directory', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='yamcs.protobuf.server.RootDirectory.type', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='totalSpace', full_name='yamcs.protobuf.server.RootDirectory.totalSpace', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unallocatedSpace', full_name='yamcs.protobuf.server.RootDirectory.unallocatedSpace', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='usableSpace', full_name='yamcs.protobuf.server.RootDirectory.usableSpace', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2976,
  serialized_end=3091,
)


_PROCESSINFO = _descriptor.Descriptor(
  name='ProcessInfo',
  full_name='yamcs.protobuf.server.ProcessInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pid', full_name='yamcs.protobuf.server.ProcessInfo.pid', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='user', full_name='yamcs.protobuf.server.ProcessInfo.user', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='command', full_name='yamcs.protobuf.server.ProcessInfo.command', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='arguments', full_name='yamcs.protobuf.server.ProcessInfo.arguments', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='startTime', full_name='yamcs.protobuf.server.ProcessInfo.startTime', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='totalCpuDuration', full_name='yamcs.protobuf.server.ProcessInfo.totalCpuDuration', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='children', full_name='yamcs.protobuf.server.ProcessInfo.children', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3094,
  serialized_end=3324,
)

_LISTTHREADSRESPONSE.fields_by_name['threads'].message_type = _THREADINFO
_LISTROUTESRESPONSE.fields_by_name['routes'].message_type = _ROUTEINFO
_LISTTOPICSRESPONSE.fields_by_name['topics'].message_type = _TOPICINFO
_HTTPTRAFFIC.fields_by_name['connections'].message_type = _CLIENTCONNECTIONINFO
_THREADGROUPINFO.fields_by_name['parent'].message_type = _THREADGROUPINFO
_THREADINFO.fields_by_name['group'].message_type = _THREADGROUPINFO
_THREADINFO.fields_by_name['trace'].message_type = _TRACEELEMENTINFO
_GETSERVERINFORESPONSE_PLUGININFO.containing_type = _GETSERVERINFORESPONSE
_GETSERVERINFORESPONSE_COMMANDOPTIONINFO.containing_type = _GETSERVERINFORESPONSE
_GETSERVERINFORESPONSE.fields_by_name['plugins'].message_type = _GETSERVERINFORESPONSE_PLUGININFO
_GETSERVERINFORESPONSE.fields_by_name['commandOptions'].message_type = _GETSERVERINFORESPONSE_COMMANDOPTIONINFO
_CLIENTCONNECTIONINFO_HTTPREQUESTINFO.containing_type = _CLIENTCONNECTIONINFO
_CLIENTCONNECTIONINFO.fields_by_name['httpRequest'].message_type = _CLIENTCONNECTIONINFO_HTTPREQUESTINFO
_SYSTEMINFO.fields_by_name['rootDirectories'].message_type = _ROOTDIRECTORY
_SYSTEMINFO.fields_by_name['process'].message_type = _PROCESSINFO
_PROCESSINFO.fields_by_name['startTime'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_PROCESSINFO.fields_by_name['totalCpuDuration'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_PROCESSINFO.fields_by_name['children'].message_type = _PROCESSINFO
DESCRIPTOR.message_types_by_name['GetThreadRequest'] = _GETTHREADREQUEST
DESCRIPTOR.message_types_by_name['ListThreadsResponse'] = _LISTTHREADSRESPONSE
DESCRIPTOR.message_types_by_name['ListRoutesResponse'] = _LISTROUTESRESPONSE
DESCRIPTOR.message_types_by_name['ListTopicsResponse'] = _LISTTOPICSRESPONSE
DESCRIPTOR.message_types_by_name['HttpTraffic'] = _HTTPTRAFFIC
DESCRIPTOR.message_types_by_name['RouteInfo'] = _ROUTEINFO
DESCRIPTOR.message_types_by_name['TopicInfo'] = _TOPICINFO
DESCRIPTOR.message_types_by_name['TraceElementInfo'] = _TRACEELEMENTINFO
DESCRIPTOR.message_types_by_name['ListThreadsRequest'] = _LISTTHREADSREQUEST
DESCRIPTOR.message_types_by_name['ThreadGroupInfo'] = _THREADGROUPINFO
DESCRIPTOR.message_types_by_name['ThreadInfo'] = _THREADINFO
DESCRIPTOR.message_types_by_name['GetServerInfoResponse'] = _GETSERVERINFORESPONSE
DESCRIPTOR.message_types_by_name['ClientConnectionInfo'] = _CLIENTCONNECTIONINFO
DESCRIPTOR.message_types_by_name['SystemInfo'] = _SYSTEMINFO
DESCRIPTOR.message_types_by_name['RootDirectory'] = _ROOTDIRECTORY
DESCRIPTOR.message_types_by_name['ProcessInfo'] = _PROCESSINFO
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetThreadRequest = _reflection.GeneratedProtocolMessageType('GetThreadRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETTHREADREQUEST,
  '__module__' : 'yamcs.protobuf.server.server_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.server.GetThreadRequest)
  })
_sym_db.RegisterMessage(GetThreadRequest)

ListThreadsResponse = _reflection.GeneratedProtocolMessageType('ListThreadsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTTHREADSRESPONSE,
  '__module__' : 'yamcs.protobuf.server.server_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.server.ListThreadsResponse)
  })
_sym_db.RegisterMessage(ListThreadsResponse)

ListRoutesResponse = _reflection.GeneratedProtocolMessageType('ListRoutesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTROUTESRESPONSE,
  '__module__' : 'yamcs.protobuf.server.server_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.server.ListRoutesResponse)
  })
_sym_db.RegisterMessage(ListRoutesResponse)

ListTopicsResponse = _reflection.GeneratedProtocolMessageType('ListTopicsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTTOPICSRESPONSE,
  '__module__' : 'yamcs.protobuf.server.server_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.server.ListTopicsResponse)
  })
_sym_db.RegisterMessage(ListTopicsResponse)

HttpTraffic = _reflection.GeneratedProtocolMessageType('HttpTraffic', (_message.Message,), {
  'DESCRIPTOR' : _HTTPTRAFFIC,
  '__module__' : 'yamcs.protobuf.server.server_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.server.HttpTraffic)
  })
_sym_db.RegisterMessage(HttpTraffic)

RouteInfo = _reflection.GeneratedProtocolMessageType('RouteInfo', (_message.Message,), {
  'DESCRIPTOR' : _ROUTEINFO,
  '__module__' : 'yamcs.protobuf.server.server_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.server.RouteInfo)
  })
_sym_db.RegisterMessage(RouteInfo)

TopicInfo = _reflection.GeneratedProtocolMessageType('TopicInfo', (_message.Message,), {
  'DESCRIPTOR' : _TOPICINFO,
  '__module__' : 'yamcs.protobuf.server.server_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.server.TopicInfo)
  })
_sym_db.RegisterMessage(TopicInfo)

TraceElementInfo = _reflection.GeneratedProtocolMessageType('TraceElementInfo', (_message.Message,), {
  'DESCRIPTOR' : _TRACEELEMENTINFO,
  '__module__' : 'yamcs.protobuf.server.server_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.server.TraceElementInfo)
  })
_sym_db.RegisterMessage(TraceElementInfo)

ListThreadsRequest = _reflection.GeneratedProtocolMessageType('ListThreadsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTTHREADSREQUEST,
  '__module__' : 'yamcs.protobuf.server.server_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.server.ListThreadsRequest)
  })
_sym_db.RegisterMessage(ListThreadsRequest)

ThreadGroupInfo = _reflection.GeneratedProtocolMessageType('ThreadGroupInfo', (_message.Message,), {
  'DESCRIPTOR' : _THREADGROUPINFO,
  '__module__' : 'yamcs.protobuf.server.server_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.server.ThreadGroupInfo)
  })
_sym_db.RegisterMessage(ThreadGroupInfo)

ThreadInfo = _reflection.GeneratedProtocolMessageType('ThreadInfo', (_message.Message,), {
  'DESCRIPTOR' : _THREADINFO,
  '__module__' : 'yamcs.protobuf.server.server_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.server.ThreadInfo)
  })
_sym_db.RegisterMessage(ThreadInfo)

GetServerInfoResponse = _reflection.GeneratedProtocolMessageType('GetServerInfoResponse', (_message.Message,), {

  'PluginInfo' : _reflection.GeneratedProtocolMessageType('PluginInfo', (_message.Message,), {
    'DESCRIPTOR' : _GETSERVERINFORESPONSE_PLUGININFO,
    '__module__' : 'yamcs.protobuf.server.server_service_pb2'
    # @@protoc_insertion_point(class_scope:yamcs.protobuf.server.GetServerInfoResponse.PluginInfo)
    })
  ,

  'CommandOptionInfo' : _reflection.GeneratedProtocolMessageType('CommandOptionInfo', (_message.Message,), {
    'DESCRIPTOR' : _GETSERVERINFORESPONSE_COMMANDOPTIONINFO,
    '__module__' : 'yamcs.protobuf.server.server_service_pb2'
    # @@protoc_insertion_point(class_scope:yamcs.protobuf.server.GetServerInfoResponse.CommandOptionInfo)
    })
  ,
  'DESCRIPTOR' : _GETSERVERINFORESPONSE,
  '__module__' : 'yamcs.protobuf.server.server_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.server.GetServerInfoResponse)
  })
_sym_db.RegisterMessage(GetServerInfoResponse)
_sym_db.RegisterMessage(GetServerInfoResponse.PluginInfo)
_sym_db.RegisterMessage(GetServerInfoResponse.CommandOptionInfo)

ClientConnectionInfo = _reflection.GeneratedProtocolMessageType('ClientConnectionInfo', (_message.Message,), {

  'HttpRequestInfo' : _reflection.GeneratedProtocolMessageType('HttpRequestInfo', (_message.Message,), {
    'DESCRIPTOR' : _CLIENTCONNECTIONINFO_HTTPREQUESTINFO,
    '__module__' : 'yamcs.protobuf.server.server_service_pb2'
    # @@protoc_insertion_point(class_scope:yamcs.protobuf.server.ClientConnectionInfo.HttpRequestInfo)
    })
  ,
  'DESCRIPTOR' : _CLIENTCONNECTIONINFO,
  '__module__' : 'yamcs.protobuf.server.server_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.server.ClientConnectionInfo)
  })
_sym_db.RegisterMessage(ClientConnectionInfo)
_sym_db.RegisterMessage(ClientConnectionInfo.HttpRequestInfo)

SystemInfo = _reflection.GeneratedProtocolMessageType('SystemInfo', (_message.Message,), {
  'DESCRIPTOR' : _SYSTEMINFO,
  '__module__' : 'yamcs.protobuf.server.server_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.server.SystemInfo)
  })
_sym_db.RegisterMessage(SystemInfo)

RootDirectory = _reflection.GeneratedProtocolMessageType('RootDirectory', (_message.Message,), {
  'DESCRIPTOR' : _ROOTDIRECTORY,
  '__module__' : 'yamcs.protobuf.server.server_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.server.RootDirectory)
  })
_sym_db.RegisterMessage(RootDirectory)

ProcessInfo = _reflection.GeneratedProtocolMessageType('ProcessInfo', (_message.Message,), {
  'DESCRIPTOR' : _PROCESSINFO,
  '__module__' : 'yamcs.protobuf.server.server_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.server.ProcessInfo)
  })
_sym_db.RegisterMessage(ProcessInfo)


DESCRIPTOR._options = None

_SERVERAPI = _descriptor.ServiceDescriptor(
  name='ServerApi',
  full_name='yamcs.protobuf.server.ServerApi',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\320\200\001\001',
  serialized_start=3327,
  serialized_end=4411,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetServerInfo',
    full_name='yamcs.protobuf.server.ServerApi.GetServerInfo',
    index=0,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_GETSERVERINFORESPONSE,
    serialized_options=b'\212\222\003\006\n\004/api',
  ),
  _descriptor.MethodDescriptor(
    name='GetSystemInfo',
    full_name='yamcs.protobuf.server.ServerApi.GetSystemInfo',
    index=1,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_SYSTEMINFO,
    serialized_options=b'\212\222\003\016\n\014/api/sysinfo',
  ),
  _descriptor.MethodDescriptor(
    name='SubscribeSystemInfo',
    full_name='yamcs.protobuf.server.ServerApi.SubscribeSystemInfo',
    index=2,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_SYSTEMINFO,
    serialized_options=b'\332\222\003\t\n\007sysinfo',
  ),
  _descriptor.MethodDescriptor(
    name='ListRoutes',
    full_name='yamcs.protobuf.server.ServerApi.ListRoutes',
    index=3,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_LISTROUTESRESPONSE,
    serialized_options=b'\212\222\003\r\n\013/api/routes',
  ),
  _descriptor.MethodDescriptor(
    name='ListTopics',
    full_name='yamcs.protobuf.server.ServerApi.ListTopics',
    index=4,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_LISTTOPICSRESPONSE,
    serialized_options=b'\212\222\003\r\n\013/api/topics',
  ),
  _descriptor.MethodDescriptor(
    name='ListThreads',
    full_name='yamcs.protobuf.server.ServerApi.ListThreads',
    index=5,
    containing_service=None,
    input_type=_LISTTHREADSREQUEST,
    output_type=_LISTTHREADSRESPONSE,
    serialized_options=b'\212\222\003\016\n\014/api/threads',
  ),
  _descriptor.MethodDescriptor(
    name='GetThread',
    full_name='yamcs.protobuf.server.ServerApi.GetThread',
    index=6,
    containing_service=None,
    input_type=_GETTHREADREQUEST,
    output_type=_THREADINFO,
    serialized_options=b'\212\222\003\023\n\021/api/threads/{id}',
  ),
  _descriptor.MethodDescriptor(
    name='DumpThreads',
    full_name='yamcs.protobuf.server.ServerApi.DumpThreads',
    index=7,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=yamcs_dot_api_dot_httpbody__pb2._HTTPBODY,
    serialized_options=b'\212\222\003\023\n\021/api/threads:dump',
  ),
  _descriptor.MethodDescriptor(
    name='GetHttpTraffic',
    full_name='yamcs.protobuf.server.ServerApi.GetHttpTraffic',
    index=8,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_HTTPTRAFFIC,
    serialized_options=b'\212\222\003%\n\021/api/http-trafficj\020Get HTTP Traffic',
  ),
  _descriptor.MethodDescriptor(
    name='SubscribeHttpTraffic',
    full_name='yamcs.protobuf.server.ServerApi.SubscribeHttpTraffic',
    index=9,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_HTTPTRAFFIC,
    serialized_options=b'\332\222\003&\n\014http-traffic\"\026Subscribe HTTP Traffic',
  ),
])
_sym_db.RegisterServiceDescriptor(_SERVERAPI)

DESCRIPTOR.services_by_name['ServerApi'] = _SERVERAPI

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yamcs/protobuf/iam/sessions_service.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yamcs.api import annotations_pb2 as yamcs_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yamcs/protobuf/iam/sessions_service.proto',
  package='yamcs.protobuf.iam',
  syntax='proto2',
  serialized_options=b'\n\022org.yamcs.protobufB\024SessionsServiceProtoP\001',
  serialized_pb=b'\n)yamcs/protobuf/iam/sessions_service.proto\x12\x12yamcs.protobuf.iam\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1byamcs/api/annotations.proto\"I\n\x14ListSessionsResponse\x12\x31\n\x08sessions\x18\x01 \x03(\x0b\x32\x1f.yamcs.protobuf.iam.SessionInfo\"\xf8\x01\n\x0bSessionInfo\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08username\x18\x02 \x01(\t\x12\x11\n\tipAddress\x18\x03 \x01(\t\x12\x10\n\x08hostname\x18\x04 \x01(\t\x12-\n\tstartTime\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x32\n\x0elastAccessTime\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x32\n\x0e\x65xpirationTime\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07\x63lients\x18\x08 \x03(\t\"%\n\x10SessionEventInfo\x12\x11\n\tendReason\x18\x01 \x01(\t2\xdd\x01\n\x0bSessionsApi\x12\x65\n\x0cListSessions\x12\x16.google.protobuf.Empty\x1a(.yamcs.protobuf.iam.ListSessionsResponse\"\x13\x8a\x92\x03\x0f\n\r/api/sessions\x12\x61\n\x10SubscribeSession\x12\x16.google.protobuf.Empty\x1a$.yamcs.protobuf.iam.SessionEventInfo\"\r\xda\x92\x03\t\n\x07session0\x01\x1a\x04\xd0\x80\x01\x01\x42,\n\x12org.yamcs.protobufB\x14SessionsServiceProtoP\x01'
  ,
  dependencies=[google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,yamcs_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_LISTSESSIONSRESPONSE = _descriptor.Descriptor(
  name='ListSessionsResponse',
  full_name='yamcs.protobuf.iam.ListSessionsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sessions', full_name='yamcs.protobuf.iam.ListSessionsResponse.sessions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=156,
  serialized_end=229,
)


_SESSIONINFO = _descriptor.Descriptor(
  name='SessionInfo',
  full_name='yamcs.protobuf.iam.SessionInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yamcs.protobuf.iam.SessionInfo.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='username', full_name='yamcs.protobuf.iam.SessionInfo.username', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ipAddress', full_name='yamcs.protobuf.iam.SessionInfo.ipAddress', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hostname', full_name='yamcs.protobuf.iam.SessionInfo.hostname', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='startTime', full_name='yamcs.protobuf.iam.SessionInfo.startTime', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lastAccessTime', full_name='yamcs.protobuf.iam.SessionInfo.lastAccessTime', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='expirationTime', full_name='yamcs.protobuf.iam.SessionInfo.expirationTime', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='clients', full_name='yamcs.protobuf.iam.SessionInfo.clients', index=7,
      number=8, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=232,
  serialized_end=480,
)


_SESSIONEVENTINFO = _descriptor.Descriptor(
  name='SessionEventInfo',
  full_name='yamcs.protobuf.iam.SessionEventInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='endReason', full_name='yamcs.protobuf.iam.SessionEventInfo.endReason', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=482,
  serialized_end=519,
)

_LISTSESSIONSRESPONSE.fields_by_name['sessions'].message_type = _SESSIONINFO
_SESSIONINFO.fields_by_name['startTime'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SESSIONINFO.fields_by_name['lastAccessTime'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SESSIONINFO.fields_by_name['expirationTime'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
DESCRIPTOR.message_types_by_name['ListSessionsResponse'] = _LISTSESSIONSRESPONSE
DESCRIPTOR.message_types_by_name['SessionInfo'] = _SESSIONINFO
DESCRIPTOR.message_types_by_name['SessionEventInfo'] = _SESSIONEVENTINFO
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListSessionsResponse = _reflection.GeneratedProtocolMessageType('ListSessionsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTSESSIONSRESPONSE,
  '__module__' : 'yamcs.protobuf.iam.sessions_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.iam.ListSessionsResponse)
  })
_sym_db.RegisterMessage(ListSessionsResponse)

SessionInfo = _reflection.GeneratedProtocolMessageType('SessionInfo', (_message.Message,), {
  'DESCRIPTOR' : _SESSIONINFO,
  '__module__' : 'yamcs.protobuf.iam.sessions_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.iam.SessionInfo)
  })
_sym_db.RegisterMessage(SessionInfo)

SessionEventInfo = _reflection.GeneratedProtocolMessageType('SessionEventInfo', (_message.Message,), {
  'DESCRIPTOR' : _SESSIONEVENTINFO,
  '__module__' : 'yamcs.protobuf.iam.sessions_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.iam.SessionEventInfo)
  })
_sym_db.RegisterMessage(SessionEventInfo)


DESCRIPTOR._options = None

_SESSIONSAPI = _descriptor.ServiceDescriptor(
  name='SessionsApi',
  full_name='yamcs.protobuf.iam.SessionsApi',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\320\200\001\001',
  serialized_start=522,
  serialized_end=743,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListSessions',
    full_name='yamcs.protobuf.iam.SessionsApi.ListSessions',
    index=0,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_LISTSESSIONSRESPONSE,
    serialized_options=b'\212\222\003\017\n\r/api/sessions',
  ),
  _descriptor.MethodDescriptor(
    name='SubscribeSession',
    full_name='yamcs.protobuf.iam.SessionsApi.SubscribeSession',
    index=1,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_SESSIONEVENTINFO,
    serialized_options=b'\332\222\003\t\n\007session',
  ),
])
_sym_db.RegisterServiceDescriptor(_SESSIONSAPI)

DESCRIPTOR.services_by_name['SessionsApi'] = _SESSIONSAPI

# @@protoc_insertion_point(module_scope)



import warnings

warnings.warn(
    "The module 'yamcs.core.helpers' is deprecated. "
    "Import classes from 'yamcs.client' instead.",
    DeprecationWarning,
    stacklevel=2,
)

from yamcs.client.core.helpers import (  # noqa
    FixedDelay,
    ProtoList,
    adapt_name_for_rest,
    delimit_protobuf,
    do_get,
    do_post,
    do_request,
    parse_server_time,
    parse_server_timestring,
    parse_value,
    split_protobuf_stream,
    to_argument_value,
    to_isostring,
    to_named_object_id,
    to_named_object_ids,
    to_server_time,
)



import urllib.parse
from typing import Any, Dict, Iterable, Mapping, Optional, Tuple

from yamcs.client.core import pagination
from yamcs.client.core.context import Context
from yamcs.client.core.helpers import adapt_name_for_rest
from yamcs.client.mdb.model import (
    Algorithm,
    Command,
    Container,
    Parameter,
    ParameterType,
    RangeSet,
    SpaceSystem,
)
from yamcs.protobuf.mdb import mdb_pb2

__all__ = [
    "MDBClient",
]


def _set_range(ar, range: Tuple[float, float], level: mdb_pb2.AlarmLevelType):
    ar.level = level
    if range[0]:
        ar.minExclusive = range[0]
    if range[1]:
        ar.maxExclusive = range[1]


def _add_alarms(
    alarm_info: mdb_pb2.AlarmInfo,
    watch: Optional[Tuple[float, float]],
    warning: Optional[Tuple[float, float]],
    distress: Optional[Tuple[float, float]],
    critical: Optional[Tuple[float, float]],
    severe: Optional[Tuple[float, float]],
    min_violations: int,
):
    alarm_info.minViolations = min_violations

    if watch:
        ar = alarm_info.staticAlarmRange.add()
        _set_range(ar, watch, mdb_pb2.WATCH)
    if warning:
        ar = alarm_info.staticAlarmRange.add()
        _set_range(ar, warning, mdb_pb2.WARNING)
    if distress:
        ar = alarm_info.staticAlarmRange.add()
        _set_range(ar, distress, mdb_pb2.DISTRESS)
    if critical:
        ar = alarm_info.staticAlarmRange.add()
        _set_range(ar, critical, mdb_pb2.CRITICAL)
    if severe:
        ar = alarm_info.staticAlarmRange.add()
        _set_range(ar, severe, mdb_pb2.SEVERE)


class MDBClient:
    def __init__(self, ctx: Context, instance: str):
        super(MDBClient, self).__init__()
        self.ctx = ctx
        self._instance = instance

    def list_space_systems(
        self, page_size: Optional[int] = None
    ) -> Iterable[SpaceSystem]:
        """
        Lists the space systems visible to this client.

        Space systems are returned in lexicographical order.
        """
        params = {}

        if page_size is not None:
            params["limit"] = page_size

        return pagination.Iterator(
            ctx=self.ctx,
            path=f"/mdb/{self._instance}/space-systems",
            params=params,
            response_class=mdb_pb2.ListSpaceSystemsResponse,
            items_key="spaceSystems",
            item_mapper=SpaceSystem,
        )

    def get_space_system(self, name: str) -> SpaceSystem:
        """
        Gets a single space system by its unique name.

        :param name:
            A fully-qualified XTCE name. Use ``/`` for root.
        """
        encoded_name = urllib.parse.quote_plus(name)
        url = f"/mdb/{self._instance}/space-systems/{encoded_name}"
        response = self.ctx.get_proto(url)
        message = mdb_pb2.SpaceSystemInfo()
        message.ParseFromString(response.content)
        return SpaceSystem(message)

    def export_space_system(self, name: str, *, version: str = "1.2") -> str:
        """
        Exports an XTCE description of a space system (XML format).

        .. versionadded:: 1.9.0
           Compatible with Yamcs 5.8.0 onwards

        :param name:
            A fully-qualified XTCE name. Use ``/`` for root.
        :param version:
            XTCE version. One of ``1.2`` or ``1.3``.

            .. versionadded:: 1.13.0
               Compatible with Yamcs 5.12.6 onwards
        """
        params: Dict[str, Any] = {"version": version}

        encoded_name = urllib.parse.quote_plus(name)
        url = f"/mdb/{self._instance}/space-systems/{encoded_name}:exportXTCE"
        response = self.ctx.get_proto(url, params=params)
        return response.text

    def list_parameters(
        self, parameter_type: Optional[str] = None, page_size: Optional[int] = None
    ) -> Iterable[Parameter]:
        """
        Lists the parameters visible to this client.

        Parameters are returned in lexicographical order.

        :param parameter_type:
            The type of parameter
        """
        params: Dict[str, Any] = {"details": True}

        if parameter_type is not None:
            params["type"] = parameter_type
        if page_size is not None:
            params["limit"] = page_size

        return pagination.Iterator(
            ctx=self.ctx,
            path=f"/mdb/{self._instance}/parameters",
            params=params,
            response_class=mdb_pb2.ListParametersResponse,
            items_key="parameters",
            item_mapper=Parameter,
        )

    def get_parameter(self, name: str) -> Parameter:
        """
        Gets a single parameter by its name.

        :param name:
            Either a fully-qualified XTCE name or an alias in the
            format ``NAMESPACE/NAME``.
        """
        name = adapt_name_for_rest(name)
        url = f"/mdb/{self._instance}/parameters{name}"
        response = self.ctx.get_proto(url)
        message = mdb_pb2.ParameterInfo()
        message.ParseFromString(response.content)
        return Parameter(message)

    def create_parameter(
        self,
        name: str,
        data_source: str,
        short_description: Optional[str] = None,
        long_description: Optional[str] = None,
        aliases: Optional[Mapping[str, str]] = None,
        parameter_type: Optional[str] = None,
    ) -> Parameter:
        """
        Create a parameter.

        .. versionadded:: 1.9.1
           Compatible with Yamcs 5.8.8 onwards

        :param name:
            Fully qualified name of the parameter.

            Space systems that do not yet exist, will be added
            automatically.
        :param data_source:
            Where this parameter originated. One of ``TELEMETERED``,
            ``GROUND``, ``DERIVED``, ``CONSTANT``, ``LOCAL``, ``SYSTEM``,
            ``COMMAND``, ``COMMAND_HISTORY``.
        :param short_description:
            Short description (one line)
        :param long_description:
            Long description (Markdown)
        :param aliases:
            Aliases, keyed by namespace.
        :param parameter_type:
            Qualified name of a parameter type. This is optional,
            but recommended. It allows specifying units, alarms and so on.
        """
        req = mdb_pb2.CreateParameterRequest()
        req.name = name
        req.dataSource = mdb_pb2.DataSourceType.Value(data_source)
        if short_description:
            req.shortDescription = short_description
        if long_description:
            req.longDescription = long_description
        if aliases:
            for namespace, alias in aliases.items():
                req.aliases[namespace] = alias
        if parameter_type:
            req.parameterType = parameter_type

        url = f"/mdb/{self._instance}/parameters"
        response = self.ctx.post_proto(url, data=req.SerializeToString())
        proto = mdb_pb2.ParameterInfo()
        proto.ParseFromString(response.content)
        return Parameter(proto)

    def list_parameter_types(
        self, page_size: Optional[int] = None
    ) -> Iterable[ParameterType]:
        """
        Lists the parameter types visible to this client.

        Parameter types are returned in lexicographical order.

        .. versionadded:: 1.9.1
           Compatible with Yamcs 5.8.8 onwards
        """
        params = {}

        if page_size is not None:
            params["limit"] = page_size

        return pagination.Iterator(
            ctx=self.ctx,
            path=f"/mdb/{self._instance}/parameter-types",
            params=params,
            response_class=mdb_pb2.ListParameterTypesResponse,
            items_key="parameterTypes",
            item_mapper=ParameterType,
        )

    def get_parameter_type(self, name: str) -> ParameterType:
        """
        Gets a single parameter type by its name.

        .. versionadded:: 1.9.1
           Compatible with Yamcs 5.8.8 onwards

        :param name:
            Either a fully-qualified XTCE name or an alias in the
            format ``NAMESPACE/NAME``.
        """
        name = adapt_name_for_rest(name)
        url = f"/mdb/{self._instance}/parameter-types{name}"
        response = self.ctx.get_proto(url)
        message = mdb_pb2.ParameterTypeInfo()
        message.ParseFromString(response.content)
        return ParameterType(message)

    def create_parameter_type(
        self,
        name: str,
        eng_type: str,
        short_description: Optional[str] = None,
        long_description: Optional[str] = None,
        aliases: Optional[Mapping[str, str]] = None,
        unit: Optional[str] = None,
        signed: Optional[bool] = None,
        enum_values: Optional[Mapping[int, str]] = None,
        one_string_value: Optional[str] = None,
        zero_string_value: Optional[str] = None,
        default_alarm: Optional[RangeSet] = None,
        context_alarms: Optional[Mapping[str, RangeSet]] = None,
    ) -> ParameterType:
        """
        Create a parameter type.

        .. versionadded:: 1.9.1
           Compatible with Yamcs 5.8.8 onwards

        :param name:
            Fully qualified name of the parameter type.

            Space systems that do not yet exist, will be added
            automatically.
        :param eng_type:
            Engineering type. One of ``float``, ``integer``, ``boolean``,
            ``binary``, ``string`` or ``enumeration``.
        :param short_description:
            Short description (one line)
        :param long_description:
            Long description (Markdown)
        :param aliases:
            Aliases, keyed by namespace.
        :param unit:
            Engineering unit
        :param signed:
            Whether the engineering type supports signed representation.
            (only used with ``integer`` parameter types)
        :param enum_values:
            Enumeration labels, keyed by integer value
            (only used with ``enumeration`` parameter types)
        :param one_string_value:
            String representation of a boolean one.
            (only used with ``boolean`` parameter types)
        :param zero_string_value:
            String representation of a boolean zero.
            (only used with ``boolean`` parameter types)
        :param default_alarm:
            Default alarm, effective when no contextual alarm takes precedence.
        :param context_alarms:
            Contextual alarms, keyed by condition.
        """
        req = mdb_pb2.CreateParameterTypeRequest()
        req.name = name
        req.engType = eng_type
        if short_description:
            req.shortDescription = short_description
        if long_description:
            req.longDescription = long_description
        if aliases:
            for namespace, alias in aliases.items():
                req.aliases[namespace] = alias
        if unit:
            req.unit = unit
        if signed is not None:
            req.signed = signed
        if enum_values:
            for value, label in enum_values.items():
                enum_value = req.enumerationValues.add()
                enum_value.value = value
                enum_value.label = label
        if one_string_value:
            req.oneStringValue = one_string_value
        if zero_string_value:
            req.zeroStringValue = zero_string_value
        if default_alarm:
            _add_alarms(
                req.defaultAlarm,
                default_alarm.watch,
                default_alarm.warning,
                default_alarm.distress,
                default_alarm.critical,
                default_alarm.severe,
                default_alarm.min_violations,
            )
        if context_alarms:
            for context, alarm in context_alarms.items():
                context_alarm = req.contextAlarms.add()
                context_alarm.context = context
                _add_alarms(
                    context_alarm.alarm,
                    alarm.watch,
                    alarm.warning,
                    alarm.distress,
                    alarm.critical,
                    alarm.severe,
                    alarm.min_violations,
                )

        url = f"/mdb/{self._instance}/parameter-types"
        response = self.ctx.post_proto(url, data=req.SerializeToString())
        proto = mdb_pb2.ParameterTypeInfo()
        proto.ParseFromString(response.content)
        return ParameterType(proto)

    def list_containers(self, page_size: Optional[int] = None) -> Iterable[Container]:
        """
        Lists the containers visible to this client.

        Containers are returned in lexicographical order.
        """
        params = {}

        if page_size is not None:
            params["limit"] = page_size

        return pagination.Iterator(
            ctx=self.ctx,
            path=f"/mdb/{self._instance}/containers",
            params=params,
            response_class=mdb_pb2.ListContainersResponse,
            items_key="containers",
            item_mapper=Container,
        )

    def get_container(self, name: str) -> Container:
        """
        Gets a single container by its unique name.

        :param name:
            Either a fully-qualified XTCE name or an alias in the
            format ``NAMESPACE/NAME``.
        """
        name = adapt_name_for_rest(name)
        url = f"/mdb/{self._instance}/containers{name}"
        response = self.ctx.get_proto(url)
        message = mdb_pb2.ContainerInfo()
        message.ParseFromString(response.content)
        return Container(message)

    def list_commands(self, page_size: Optional[int] = None) -> Iterable[Command]:
        """
        Lists the commands visible to this client.

        Commands are returned in lexicographical order.
        """
        params = {}

        if page_size is not None:
            params["limit"] = page_size

        return pagination.Iterator(
            ctx=self.ctx,
            path=f"/mdb/{self._instance}/commands",
            params=params,
            response_class=mdb_pb2.ListCommandsResponse,
            items_key="commands",
            item_mapper=Command,
        )

    def get_command(self, name: str) -> Command:
        """
        Gets a single command by its unique name.

        :param name:
            Either a fully-qualified XTCE name or an alias in the
            format ``NAMESPACE/NAME``.
        """
        name = adapt_name_for_rest(name)
        url = f"/mdb/{self._instance}/commands{name}"
        response = self.ctx.get_proto(url)
        message = mdb_pb2.CommandInfo()
        message.ParseFromString(response.content)
        return Command(message)

    def list_algorithms(self, page_size: Optional[int] = None) -> Iterable[Algorithm]:
        """
        Lists the algorithms visible to this client.

        Algorithms are returned in lexicographical order.
        """
        params = {}

        if page_size is not None:
            params["limit"] = page_size

        return pagination.Iterator(
            ctx=self.ctx,
            path=f"/mdb/{self._instance}/algorithms",
            params=params,
            response_class=mdb_pb2.ListAlgorithmsResponse,
            items_key="algorithms",
            item_mapper=Algorithm,
        )

    def get_algorithm(self, name: str) -> Algorithm:
        """
        Gets a single algorithm by its unique name.

        :param name:
            Either a fully-qualified XTCE name or an alias in the
            format ``NAMESPACE/NAME``.
        """
        name = adapt_name_for_rest(name)
        url = f"/mdb/{self._instance}/algorithms{name}"
        response = self.ctx.get_proto(url)
        message = mdb_pb2.AlgorithmInfo()
        message.ParseFromString(response.content)
        return Algorithm(message)
